<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class ManageCourses extends CI_Controller {

	/* 
	 * tempLogin and tempLogout are temporary functions to debug user validation functionality
	 * They should be removed when lenasys is complete
	 */

	public function tempLogin() {
		$this->load->model('user');
		$loginDetails = array(
			'username' => 'tempTeacher',
			'name' => 'tempFoo',
			'usertype' => 'Teacher',
			'ssn' => '0000');
		$this->session->set_userdata('authenticated', $loginDetails);
		redirect('/ManageCourses');
	}

	public function tempLogout() {
		$this->load->model('user');
		$this->session->unset_userdata('authenticated');
		redirect('/ManageCourses');
	}


	/*
	 *	Manage courses index page
	 *  RESTRICTED-LEVEL: Teacher
	 */
	public function index()
	{
		/* Loads used models */
		$this->load->model('user');
		$this->load->model('admin/admin_model');
		$this->load->model('ExamplesModel');

		$this->load->library('session');
		$this->load->helper('form');
		
		// Arrays
		$headTagData = array(
			'cssFiles' => array('header', 'examplesMenu', 'manageCoursesBody'),
			'jsFiles' => array('header', 'examplesMenu', 'examplesBody', 'userControls', 'manageCourses')
		);

		$userInfo = array(
			'userType' => $this->user->getUserType(), // Loads different header for teacher/student
			'userName' => $this->user->getUserName()
		);

		
		$allTitles = array();
		$allCourses = array();
		
		/* Loads categorydata into $allTitles */
		$query = $this->ExamplesModel->getTitles($userInfo['userName']);
		foreach ($query as $category)
		{
			// Category
			$query2 = $this->ExamplesModel->getBody($category->categoryName);
			$allTitles[$category->categoryName.",".$category->courseID] = array();
		//	$allTitles[$category->categoryName] = array();
		//	$allTitles[$category->courseID] = array();
						foreach ($query2 as $subCategory)
			{
				// Subcategory
				$query3 = $this->ExamplesModel->getExamples($subCategory->subCategoryName);
				$allTitles[$category->categoryName][$subCategory->subCategoryName] = array();
				foreach ($query3 as $examples)
				{
					//Examples
					$allTitles[$category->categoryName][$subCategory->subCategoryName][] = $examples->exampleName;
				}

			}
		}

		/* Loads views */
		$this->load->view('headTag', array('headTagData' => $headTagData));
		$this->load->view('header', $userInfo);
		$this->load->view('examplesMenu', array('titles' => $allTitles));	

		// Check user login and display message if not logged in
				// User has to be logged in and usertype has to be Tea
		if(!$this->user->isLoggedIn() || $this->user->getUserType() != "Teacher") {
			$this->load->view('manageCoursesMessage', array('message' => 'You do not have access to this page'));
			return;
		}

		/* Loads coursedata into $allCourses */
		$courses = $this->admin_model->getCourses();

		$this->load->view('manageCoursesBody', array("courses" => $courses));	

	}


	/*
	 *	Add course page - handles form submission from index page 
	 *  RESTRICTED-LEVEL: Teacher
	 */
	public function addCourse(){
		$this->load->model('user');

		// User has to be logged in and usertype has to be Tea
		if(!$this->user->isLoggedIn() || $this->user->getUserType() != "Teacher") {
			$this->load->view('manageCoursesMessage', array('message' => 'You do not have access to this page'));
			return;
		}

		/* 
			To do: 
				Login validation
				Input validation
		*/
		if($this->input->post('cid')){
			$this->load->model('admin/admin_model');
			$this->admin_model->addCourse($_POST['cid'], $_POST['name'], $_POST['courseData']);
			redirect("/ManageCourses");
		}
		else{
			redirect("/ManageCourses");
		}
	} 	

	/*
	 *	Edit course page - handles form submission from index page 
	 *  RESTRICTED-LEVEL: Teacher
	 */
	function editCourse() {
		$this->load->model('user');
		// User has to be logged in and usertype has to be Teacher
		if(!$this->user->isLoggedIn() || $this->user->getUserType() != "Teacher") {
			$this->load->view('manageCoursesMessage', array('message' => 'You do not have access to this page'));
			return;
		}

		if($this->input->post('editCourseID')) {
			$this->load->model('admin/admin_model');
			$this->admin_model->editCourse($this->input->post('editCourseID'), $this->input->post('editCourseName'), $this->input->post('editCourseData'));
			redirect('/ManageCourses');
		} else {
			echo "Something went wrong";
		}
	}
	
	public function validate() {
		//Load required library
		$this->load->library('form_validation');
		
		//Sets validation rules
		$this->form_validation->set_rules('username', 'Username', 'trim|required|xss_clean');
		$this->form_validation->set_rules('password', 'Password', 'trim|required|xss_clean');
		
		//Run validation
		if($this->form_validation->run() == FALSE) {
			//Field validation failed. Display login form (with error message).
			$this->drawLoginForm(validation_errors());
		} else {
			$username = $this->input->post('username');
			$password = $this->input->post('password');
			
			//Try to login
			if ($this->user->login($username, $password)) {
				redirect(base_url().'home', 'refresh');
			} else {
				$this->drawLoginForm('Access denied!');
			}
		}
	}

	public function manageCourse($cid) {
		$cid = urldecode($cid);
		$this->load->model('admin/Admin_model');
		$categories = $this->Admin_model->getCategories($cid);
		$this->load->view('admin/header', array("title" => "Manage course - ".$cid));
		$menu = $this->Admin_model->getMenu();
		$this->load->view('admin/menu', array("menu" => $menu));
		$this->load->view('admin/manage_course', array("categories" => $categories, "cid" => $cid));
	}
	
}

/* End of file ManageCourses.php */
/* Location: ./application/controllers/ExamplesController.php */